---
name: Help wanted
about: Create a help request about repository or automation
title: "[HELP]"
labels: ''
assignees: ''

---

**Your purpose**
Are you trying to pass a web site protection or can't find the required keys? Can't submit the captcha? Or something else.. Please explain it in here.

**Highly required informations**
- Web site url (where placed the captcha)

**Things you've tried**
The followed way to solve your problem. Explain it briefly, like I changed ... to ... but it doesn't worked

**Do not forget**
90% of help requests was about submitting captcha in web sites. In this cases, please take a look at to **examples**
